#ifndef __USER_INTERFACE_H
#define __USER_INTERFACE_H


#include "Pxi61xx_CommonDefinition.h"

/**********************************************
*        definitions only for information 
**********************************************/
#define K_6100_DLL_VERSION				164
#define K_6100_MAX_DEVICE				16
#define K_6100_MAX_TRANSCEIVER			7


// Aufteilung 12 Byte Header
#define K_HEADER_POS_START_BYTE			0
#define K_HEADER_POS_FLAGS				1
#define K_HEADER_POS_LENGTH_LOW			2
#define K_HEADER_POS_LENGTH_HIGH		3
#define K_HEADER_POS_TARGET_ADDRESS		4  // bei PXI Portnummer
#define K_HEADER_POS_TARGET_PORT		5
#define K_HEADER_POS_SOURCE_ADDRESS		6
#define K_HEADER_POS_SOURCE_PORT		7
#define K_HEADER_POS_TYPE				8
#define K_HEADER_POS_APPLICATIONHANDLE	9
#define K_HEADER_POS_DEVICE				10  // bei PXI Kartennummer
#define K_HEADER_POS_COMMAND			11

#define K_NUMBER_COUNT_HEADER			12

#define K_START_BYTE_CMD				0x23

#define K_HEADER_FLAG_NO_ACK			0
#define K_HEADER_FLAG_ACK				1
#define K_HEADER_FLAG_ACK_ON_ERROR		2

#define K_HEADER_TYPE_CMD				0
#define K_HEADER_TYPE_RESPONSE			1
#define K_HEADER_TYPE_ACK				2








/**********************************************
*               Structures
**********************************************/
typedef struct
	{
	U32	GeoAddress;
	U32	SerialNumber;	
	U32	SwVersionFpga_CU_FLEX;
	U32	HwVersionFpga_CU_FLEX;
	U32	HwNameXilinx_CU_FLEX;
	U32	FpgaType_CU_FLEX;
	U32	FpgaReserved1_CU_FLEX;
	U32	FpgaReserved2_CU_FLEX;
	U32	SwVersionFpga_CAN_LIN;
	U32	HwVersionFpga_CAN_LIN;
	U32	HwNameXilinx_CAN_LIN;
	U32	FpgaType_CAN_LIN;
	U32	FpgaReserved1_CAN_LIN;
	U32	FpgaReserved2_CAN_LIN;
	U32	HwVariants_LIST;
	U32	SwVariants_TP;
	U32	SwVariants_DIAG;
	U32	SwVariants_DDP;
	U32	SwVariants_USER;
	U32	CardType;
	U32	MAC_Address;
	U32	Interfaces;
	U32	IP_Address;
	U32	Mode;
	U32 TCP_Port;
	U32	reserved1;
	U32	reserved2;
	U32	reserved3;
	U32	reserved4;
	} t_Card_Info;

typedef struct
	{
	U32	PID;
	U32	reserved1;
	U32	reserved2;
	U32	reserved3;
	U32	reserved4;
	} t_Card_Info_Special;

typedef struct
	{
	U32	Transceiver_Type[K_6100_MAX_TRANSCEIVER];
	U32	Transceiver_IC_Type[K_6100_MAX_TRANSCEIVER];
	U32	Transceiver_Serialnummer[K_6100_MAX_TRANSCEIVER];
	U32	Transceiver_AdditionalInfo[K_6100_MAX_TRANSCEIVER];
	U32	Transceiver_Reserved2[K_6100_MAX_TRANSCEIVER];
	U32	Transceiver_Reserved3[K_6100_MAX_TRANSCEIVER];
	U32	Transceiver_Reserved4[K_6100_MAX_TRANSCEIVER];
	} t_Card_Transceiver_Info;

typedef struct
	{
	U32				DllVersion;
	U32				DriverVersion;
	U32				CardCount;
	t_Card_Info		CardInfo[K_6100_MAX_DEVICE];
	} t_System_Info;

typedef struct
	{
	U32						DllVersion;
	U32						DriverVersion;
	U32						CardCount;
	t_Card_Info_Special		CardInfoSpecial[K_6100_MAX_DEVICE];
	} t_System_Info_Special;

typedef struct
	{
	U32						TransceiverCount[K_6100_MAX_DEVICE];
	t_Card_Transceiver_Info	CardTransceiverInfo[K_6100_MAX_DEVICE];
	} t_Transceiver_Properties;

typedef struct
	{
	U32	PciBarBaseAddress[K_USED_BAR_MEM];
	U32	PciBarRange[K_USED_BAR_MEM];
	U32	MemoryType[K_USED_BAR_MEM];                     // 0 -> IO ; 1 -> Memory
	} t_MemProperties;

/******************************************
 * Goepel function
 *****************************************/
#ifdef __EXPORT_DLL	// creating DLL
	#define INTEGRATION_MODE	__declspec(dllexport)
#else				// using in customer application
	#define INTEGRATION_MODE	__declspec(dllimport)
#endif

#ifdef __cplusplus
	extern "C" {
#endif



INTEGRATION_MODE		S32
						Pxi61xx__SystemInfo(
												t_System_Info	*pSystemInfo,
												U32				LengthInByte);
INTEGRATION_MODE		S32	Pxi61xx__SystemInfoSpecial(
												t_System_Info_Special	*pSystemInfoSpecial,
												U32						LengthInByte);
INTEGRATION_MODE		S32
						Pxi61xx__TransceiverInfo(
												t_Transceiver_Properties	*pTransceiverProperties,
												U32							LengthInByte);
INTEGRATION_MODE		S32
						Pxi61xx__WriteInstruction(
												U8		*pData, 
												U16		DataLength);
INTEGRATION_MODE		S32
						Pxi61xx__ReadResponse(
												U8		Device,
												U8		*pData, 
												U32		*DataLength);
INTEGRATION_MODE		S32
						Pxi61xx__ReadResponseBlock(
												U8		Device,
												U8		*pData, 
												U32		*DataLength,
												U32		*BlockCounter);
INTEGRATION_MODE		S32
						Pxi61xx__ReadMonitor(
												U8		Device,
												U8		*pData, 
												U32		*DataLength,
												U32		*BlockCounter);


// interrupt support function
INTEGRATION_MODE		S32	Pxi61xx__SetInterruptSource(
												U8		Device);
INTEGRATION_MODE		S32	Pxi61xx__NotificationInit(
												HANDLE				hDevice,
												t_PPC_INTR			*pInterrupt,
												t_NOTIFY_OBJECT		*pEvent);
INTEGRATION_MODE		S32	Pxi61xx__NotificationWait(
												HANDLE				hDevice,
												t_NOTIFY_OBJECT		*pEvent,
												U32					Timeout_ms);
INTEGRATION_MODE		S32	Pxi61xx__NotificationCancel(
												HANDLE				hDevice,
												t_NOTIFY_OBJECT		*pEvent);







#ifdef __cplusplus
	}
#endif


#endif
